@@ -1,25 +1,26 @@
 package PEF::Front::WebSocket::Interface;
-use base 'PEF::Front::WebSocket::Base';
 use warnings;
 use strict;
 
 sub on_message {
-
 }
 
 sub on_drain {
-
 }
 
 sub on_open {
-
 }
 
 sub on_error {
 }
 
-sub on_close {
+sub on_queue {
+}
 
+sub on_queue_error {
+}
+
+sub on_close {
 }
 
 1;
